<div align="center">
  <img src="doc/images/logo.png"><br>
</div>

# RUL-PM
-----------------


# RUL-PM: python Remaining Useful Life estimation toolkit

[![Coverage Status](https://coveralls.io/repos/github/lucianolorenti/rul_pm/badge.svg?branch=main&t=dYuRdM)](https://coveralls.io/github/lucianolorenti/rul_pm?branch=main)
[![Documentation](https://img.shields.io/badge/documentation-dev-brightgreen)](https://lucianolorenti.github.io/rul_pm/)

## What is it?

**RUL-PM** is a Python package that provides a flexible environment designed to make working with predictive maintenance task both easy and intuitive. (Yes, I stole that from pandas readme)

## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/lucianolorenti/rul_pm

```sh
git clone https://github.com/lucianolorenti/rul_pm
pip install [-e] rul_pm
```

## Main Features

* Model fitting for RUL regression on PM datasets.
* Model evaluation and comparison through metrics and plots

## Example
Take a look at the [Getting Started Guide](https://lucianolorenti.github.io/rul_pm/examples/ExampleAircraftEngine.html)


This library relies on Temporis [Temporis](https://github.com/lucianolorenti/Temporis) for handling PM datasets and feature extraction.

 Made with <3 @   <a href="https://www.dei.unipd.it/">  
         <img alt="University of Padova" src="doc/images/unipd_logo.png" width=100 />
      </a>
